@@ -6,12 +6,12 @@ import json
 import platform
 import time
 import uuid
+import warnings
 
 import stripe
 from stripe import error, oauth_error, http_client, version, util, six
 from stripe.multipart_data_generator import MultipartDataGenerator
 from stripe.six.moves.urllib.parse import urlencode, urlsplit, urlunsplit
-from stripe.request_metrics import RequestMetrics
 from stripe.stripe_response import StripeResponse
 
 
@@ -31,10 +31,6 @@ def _encode_nested_dict(key, data, fmt="%s[%s]"):
     return d
 
 
-def _now_ms():
-    return int(round(time.time() * 1000))
-
-
 def _api_encode(data):
     for key, value in six.iteritems(data):
         key = util.utf8(key)
@@ -83,18 +79,31 @@ class APIRequestor(object):
         self.api_version = api_version or stripe.api_version
         self.stripe_account = account
 
+        self._default_proxy = None
+
         from stripe import verify_ssl_certs as verify
         from stripe import proxy
 
-        self._client = (
-            client
-            or stripe.default_http_client
-            or http_client.new_default_http_client(
+        if client:
+            self._client = client
+        elif stripe.default_http_client:
+            self._client = stripe.default_http_client
+            if proxy != self._default_proxy:
+                warnings.warn(
+                    "stripe.proxy was updated after sending a "
+                    "request - this is a no-op. To use a different proxy, "
+                    "set stripe.default_http_client to a new client "
+                    "configured with the proxy."
+                )
+        else:
+            # If the stripe.default_http_client has not been set by the user
+            # yet, we'll set it here. This way, we aren't creating a new
+            # HttpClient for every request.
+            stripe.default_http_client = http_client.new_default_http_client(
                 verify_ssl_certs=verify, proxy=proxy
             )
-        )
-
-        self._last_request_metrics = None
+            self._client = stripe.default_http_client
+            self._default_proxy = proxy
 
     @classmethod
     def format_app_info(cls, info):
@@ -261,11 +270,6 @@ class APIRequestor(object):
         if self.api_version is not None:
             headers["Stripe-Version"] = self.api_version
 
-        if stripe.enable_telemetry and self._last_request_metrics:
-            headers["X-Stripe-Client-Telemetry"] = json.dumps(
-                {"last_request_metrics": self._last_request_metrics.payload()}
-            )
-
         return headers
 
     def request_raw(self, method, url, params=None, supplied_headers=None):
@@ -335,8 +339,6 @@ class APIRequestor(object):
             api_version=self.api_version,
         )
 
-        request_start = _now_ms()
-
         rbody, rcode, rheaders = self._client.request_with_retries(
             method, abs_url, headers, post_data
         )
@@ -350,11 +352,6 @@ class APIRequestor(object):
                 "Dashboard link for request",
                 link=util.dashboard_link(request_id),
             )
-            if stripe.enable_telemetry:
-                request_duration_ms = _now_ms() - request_start
-                self._last_request_metrics = RequestMetrics(
-                    request_id, request_duration_ms
-                )
 
         return rbody, rcode, rheaders, my_api_key
 
@@ -371,7 +368,7 @@ class APIRequestor(object):
                 rcode,
                 rheaders,
             )
-        if not (200 <= rcode < 300):
+        if not 200 <= rcode < 300:
             self.handle_error_response(rbody, rcode, resp.data, rheaders)
 
         return resp
