@@ -4,6 +4,13 @@ from __future__ import absolute_import, division, print_function
 
 from stripe.api_resources.list_object import ListObject
 
+from stripe.api_resources import checkout
+from stripe.api_resources import issuing
+from stripe.api_resources import radar
+from stripe.api_resources import reporting
+from stripe.api_resources import sigma
+from stripe.api_resources import terminal
+
 from stripe.api_resources.account import Account
 from stripe.api_resources.account_link import AccountLink
 from stripe.api_resources.alipay_account import AlipayAccount
@@ -15,12 +22,16 @@ from stripe.api_resources.balance_transaction import BalanceTransaction
 from stripe.api_resources.bank_account import BankAccount
 from stripe.api_resources.bitcoin_receiver import BitcoinReceiver
 from stripe.api_resources.bitcoin_transaction import BitcoinTransaction
+from stripe.api_resources.capability import Capability
 from stripe.api_resources.card import Card
 from stripe.api_resources.charge import Charge
-from stripe.api_resources.checkout_session import CheckoutSession
 from stripe.api_resources.country_spec import CountrySpec
 from stripe.api_resources.coupon import Coupon
+from stripe.api_resources.credit_note import CreditNote
 from stripe.api_resources.customer import Customer
+from stripe.api_resources.customer_balance_transaction import (
+    CustomerBalanceTransaction,
+)
 from stripe.api_resources.dispute import Dispute
 from stripe.api_resources.ephemeral_key import EphemeralKey
 from stripe.api_resources.event import Event
@@ -36,6 +47,7 @@ from stripe.api_resources.login_link import LoginLink
 from stripe.api_resources.order import Order
 from stripe.api_resources.order_return import OrderReturn
 from stripe.api_resources.payment_intent import PaymentIntent
+from stripe.api_resources.payment_method import PaymentMethod
 from stripe.api_resources.payout import Payout
 from stripe.api_resources.person import Person
 from stripe.api_resources.plan import Plan
@@ -45,11 +57,18 @@ from stripe.api_resources.recipient_transfer import RecipientTransfer
 from stripe.api_resources.refund import Refund
 from stripe.api_resources.reversal import Reversal
 from stripe.api_resources.review import Review
+from stripe.api_resources.setup_intent import SetupIntent
 from stripe.api_resources.sku import SKU
 from stripe.api_resources.source import Source
 from stripe.api_resources.source_transaction import SourceTransaction
 from stripe.api_resources.subscription import Subscription
 from stripe.api_resources.subscription_item import SubscriptionItem
+from stripe.api_resources.subscription_schedule import SubscriptionSchedule
+from stripe.api_resources.subscription_schedule_revision import (
+    SubscriptionScheduleRevision,
+)
+from stripe.api_resources.tax_id import TaxId
+from stripe.api_resources.tax_rate import TaxRate
 from stripe.api_resources.three_d_secure import ThreeDSecure
 from stripe.api_resources.token import Token
 from stripe.api_resources.topup import Topup
