@@ -1,7 +1,7 @@
 from __future__ import absolute_import, division, print_function
 
-from stripe.api_resources import abstract
+from stripe.api_resources.abstract import ListableAPIResource
 
 
-class CountrySpec(abstract.ListableAPIResource):
+class CountrySpec(ListableAPIResource):
     OBJECT_NAME = "country_spec"
