@@ -1,6 +1,7 @@
 from __future__ import absolute_import, division, print_function
 
-from stripe import error, util
+from stripe import error
+from stripe import util
 from stripe.api_resources import Customer
 from stripe.api_resources.abstract import CreateableAPIResource
 from stripe.api_resources.abstract import UpdateableAPIResource
