@@ -6,9 +6,12 @@ import warnings
 import email
 import time
 import random
+import threading
+import json
 
 import stripe
 from stripe import error, util, six
+from stripe.request_metrics import RequestMetrics
 
 # - Requests is the preferred HTTP library
 # - Google App Engine has urlfetch
@@ -60,6 +63,10 @@ except ImportError:
 from stripe.six.moves.urllib.parse import urlparse
 
 
+def _now_ms():
+    return int(round(time.time() * 1000))
+
+
 def new_default_http_client(*args, **kwargs):
     if urlfetch:
         impl = UrlFetchClient
@@ -87,9 +94,9 @@ class HTTPClient(object):
     def __init__(self, verify_ssl_certs=True, proxy=None):
         self._verify_ssl_certs = verify_ssl_certs
         if proxy:
-            if type(proxy) is str:
+            if isinstance(proxy, str):
                 proxy = {"http": proxy, "https": proxy}
-            if not (type(proxy) is dict):
+            if not isinstance(proxy, dict):
                 raise ValueError(
                     "Proxy(ies) must be specified as either a string "
                     "URL or a dict() with string URL under the"
@@ -101,10 +108,16 @@ class HTTPClient(object):
                 )
         self._proxy = proxy.copy() if proxy else None
 
+        self._thread_local = threading.local()
+
     def request_with_retries(self, method, url, headers, post_data=None):
+        self._add_telemetry_header(headers)
+
         num_retries = 0
 
         while True:
+            request_start = _now_ms()
+
             try:
                 num_retries += 1
                 response = self.request(method, url, headers, post_data)
@@ -131,6 +144,8 @@ class HTTPClient(object):
                 time.sleep(sleep_time)
             else:
                 if response is not None:
+                    self._record_request_metrics(response, request_start)
+
                     return response
                 else:
                     raise connection_error
@@ -179,6 +194,25 @@ class HTTPClient(object):
         sleep_seconds *= 0.5 * (1 + random.uniform(0, 1))
         return sleep_seconds
 
+    def _add_telemetry_header(self, headers):
+        last_request_metrics = getattr(
+            self._thread_local, "last_request_metrics", None
+        )
+        if stripe.enable_telemetry and last_request_metrics:
+            telemetry = {
+                "last_request_metrics": last_request_metrics.payload()
+            }
+            headers["X-Stripe-Client-Telemetry"] = json.dumps(telemetry)
+
+    def _record_request_metrics(self, response, request_start):
+        _, _, rheaders = response
+        if "Request-Id" in rheaders and stripe.enable_telemetry:
+            request_id = rheaders["Request-Id"]
+            request_duration_ms = _now_ms() - request_start
+            self._thread_local.last_request_metrics = RequestMetrics(
+                request_id, request_duration_ms
+            )
+
     def close(self):
         raise NotImplementedError(
             "HTTPClient subclasses must implement `close`"
@@ -190,8 +224,8 @@ class RequestsClient(HTTPClient):
 
     def __init__(self, timeout=80, session=None, **kwargs):
         super(RequestsClient, self).__init__(**kwargs)
+        self._session = session
         self._timeout = timeout
-        self._session = session or requests.Session()
 
     def request(self, method, url, headers, post_data=None):
         kwargs = {}
@@ -203,9 +237,12 @@ class RequestsClient(HTTPClient):
         if self._proxy:
             kwargs["proxies"] = self._proxy
 
+        if getattr(self._thread_local, "session", None) is None:
+            self._thread_local.session = self._session or requests.Session()
+
         try:
             try:
-                result = self._session.request(
+                result = self._thread_local.session.request(
                     method,
                     url,
                     headers=headers,
@@ -248,8 +285,9 @@ class RequestsClient(HTTPClient):
             err = "%s: %s" % (type(e).__name__, str(e))
             should_retry = False
         # Retry only timeout and connect errors; similar to urllib3 Retry
-        elif isinstance(e, requests.exceptions.Timeout) or isinstance(
-            e, requests.exceptions.ConnectionError
+        elif isinstance(
+            e,
+            (requests.exceptions.Timeout, requests.exceptions.ConnectionError),
         ):
             msg = (
                 "Unexpected error communicating with Stripe.  "
@@ -285,8 +323,8 @@ class RequestsClient(HTTPClient):
         raise error.APIConnectionError(msg, should_retry=should_retry)
 
     def close(self):
-        if self._session is not None:
-            self._session.close()
+        if getattr(self._thread_local, "session", None) is not None:
+            self._thread_local.session.close()
 
 
 class UrlFetchClient(HTTPClient):
@@ -374,8 +412,8 @@ class PycurlClient(HTTPClient):
         if self._proxy:
             # now that we have the parser, get the proxy url pieces
             proxy = self._proxy
-            for scheme in proxy:
-                proxy[scheme] = urlparse(proxy[scheme])
+            for scheme, value in six.iteritems(proxy):
+                proxy[scheme] = urlparse(value)
 
     def parse_headers(self, data):
         if "\r\n" not in data:
@@ -477,11 +515,7 @@ class PycurlClient(HTTPClient):
             proxy = self._proxy
             scheme = url.split(":")[0] if url else None
             if scheme:
-                if scheme in proxy:
-                    return proxy[scheme]
-                scheme = scheme[0:-1]
-                if scheme in proxy:
-                    return proxy[scheme]
+                return proxy.get(scheme, proxy.get(scheme[0:-1]))
         return None
 
     def close(self):
