@@ -18,13 +18,12 @@ class Webhook(object):
     ):
         if hasattr(payload, "decode"):
             payload = payload.decode("utf-8")
-        if api_key is None:
-            api_key = stripe.api_key
-        data = json.loads(payload)
-        event = stripe.Event.construct_from(data, api_key)
 
         WebhookSignature.verify_header(payload, sig_header, secret, tolerance)
 
+        data = json.loads(payload)
+        event = stripe.Event.construct_from(data, api_key or stripe.api_key)
+
         return event
 
 
@@ -60,7 +59,7 @@ class WebhookSignature(object):
                 payload,
             )
 
-        if len(signatures) == 0:
+        if not signatures:
             raise error.SignatureVerificationError(
                 "No signatures found with expected scheme "
                 "%s" % cls.EXPECTED_SCHEME,
