@@ -7,27 +7,27 @@ from stripe.stripe_response import StripeResponse
 
 class TestStripeResponse(object):
     def test_idempotency_key(self):
-        response, headers, body, code = self.mock_stripe_response()
+        response, headers, _, _ = self.mock_stripe_response()
         assert response.idempotency_key == headers["idempotency-key"]
 
     def test_request_id(self):
-        response, headers, body, code = self.mock_stripe_response()
+        response, headers, _, _ = self.mock_stripe_response()
         assert response.request_id == headers["request-id"]
 
     def test_code(self):
-        response, headers, body, code = self.mock_stripe_response()
+        response, _, _, code = self.mock_stripe_response()
         assert response.code == code
 
     def test_headers(self):
-        response, headers, body, code = self.mock_stripe_response()
+        response, headers, _, _ = self.mock_stripe_response()
         assert response.headers == headers
 
     def test_body(self):
-        response, headers, body, code = self.mock_stripe_response()
+        response, _, body, _ = self.mock_stripe_response()
         assert response.body == body
 
     def test_data(self):
-        response, headers, body, code = self.mock_stripe_response()
+        response, _, body, _ = self.mock_stripe_response()
         assert response.data == json.loads(body)
 
     @staticmethod
